@@ -4,7 +4,7 @@
 import re
 import configparser
 
-from i3pystatus import IntervalModule
+from i3pystatus import IntervalModule, formatp
 from i3pystatus.core.util import PrefixedKeyDict, lchop, TimeWrapper
 from i3pystatus.core.desktop import display_notification
 
@@ -152,8 +152,8 @@ class BatteryChecker(IntervalModule):
 
         if self.alert and fdict["status"] == "DIS" and fdict["percentage"] <= self.alert_percentage:
             display_notification(
-                title=self.alert_format_title.format(**fdict),
-                body=self.alert_format_body.format(**fdict),
+                title= formatp(self.alert_format_title, **fdict),
+                body=formatp(self.alert_format_body, **fdict),
                 icon="battery-caution",
                 urgency=2,
             )
@@ -161,7 +161,7 @@ class BatteryChecker(IntervalModule):
         fdict["status"] = self.status[fdict["status"]]
 
         self.output = {
-            "full_text": self.format.format(**fdict).strip(),
+            "full_text": formatp(self.format, **fdict).strip(),
             "instance": self.battery_ident,
             "urgent": urgent,
             "color": color
