@@ -106,25 +106,28 @@ def get_module(finder, modname):
     fullname = "i3pystatus.{modname}".format(modname=modname)
     return (modname, finder.find_loader(fullname)[0].load_module(fullname))
 
-def get_all(module_path, heading, finder=None):
+def get_all(module_path, heading, finder=None, ignore=None):
     mods = []
     if not finder:
         finder = ClassFinder(i3pystatus.Module)
 
     for name, module in get_modules(module_path):
         classes = finder.search_module(module)
+        found = []
         for cls in classes:
-            mods.append(Module(cls, neighbours=len(classes), module_name=name, module=module, heading=heading))
+            if cls.__name__ not in found:
+                found.append(cls.__name__)
+                mods.append(Module(cls, neighbours=len(classes), module_name=name, module=module, heading=heading))
 
     return sorted(mods, key=lambda module: module.name)
 
-def generate_doc_for_module(module_path, heading="###", finder=None):
-    return "".join(map(str, get_all(module_path, heading, finder)))
+def generate_doc_for_module(module_path, heading="###", finder=None, ignore=None):
+    return "".join(map(str, get_all(module_path, heading, finder, ignore or [])))
 
 with open("README.tpl.md", "r") as template:
     tpl = template.read()
     tpl = tpl.replace("!!module_doc!!", generate_doc_for_module(i3pystatus.__path__))
     finder = ClassFinder(baseclass=i3pystatus.mail.Backend)
-    tpl = tpl.replace("!!i3pystatus.mail!!", generate_doc_for_module(i3pystatus.mail.__path__, "###", finder).replace("\n", "\n> "))
+    tpl = tpl.replace("!!i3pystatus.mail!!", generate_doc_for_module(i3pystatus.mail.__path__, "###", finder, ["Backend"]).replace("\n", "\n> "))
     with open("README.md", "w") as output:
         output.write(tpl + "\n")
